@@ -7,11 +7,10 @@ from jsonpkt.utils import parse_packet_json
 
 
 class SendCommand(BaseCommand):
-    def process(self, args):
-        file = args.file
+    def process(self, file: str, layer: int = 3):
         with open(file) as fp:
             packet_json = json.load(fp)
             packet = parse_packet_json(packet_json)
-            sender = scapy.sendp if args.layer < 3 else scapy.send
+            sender = scapy.sendp if layer < 3 else scapy.send
             sender(packet, verbose=False)
         
